@@ -18,7 +18,9 @@
 
 #ifdef _WIN32
  #ifndef __MINGW32__
-  #define snprintf _snprintf
+   #ifndef snprintf
+    #define snprintf _snprintf
+   #endif
  #endif
  #include <io.h> //access
  #define access _access
@@ -112,7 +114,7 @@ void NodePropertiesDlg::Create()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chk_finished), m_bFinished);
 }
 
-const char *NodePropertiesDlg::GetNodeTitle()
+std::string NodePropertiesDlg::GetNodeTitle()
 {
 	GtkWidget *entry = lookup_widget(m_pDialog, "entry_node_title");
 	//return gtk_entry_get_text(GTK_ENTRY(entry));
@@ -120,7 +122,10 @@ const char *NodePropertiesDlg::GetNodeTitle()
 	GtkTextIter start,end;
 	gtk_text_buffer_get_start_iter(buffer, &start);
 	gtk_text_buffer_get_end_iter(buffer, &end);
-	return gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
+	gchar *pszData = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
+	std::string strData = pszData;
+	g_free(pszData);
+	return strData;
 }
 
 void NodePropertiesDlg::RefreshKeywords()
@@ -473,7 +478,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	gtk_widget_show (removebtn);
 	gtk_box_pack_start (GTK_BOX (hbox3), removebtn, TRUE, TRUE, 0);
 
-	chk_finished = gtk_check_button_new_with_mnemonic (_("Mark node as finished"));
+	chk_finished = gtk_check_button_new_with_mnemonic (_("Mark node as Completed"));
 	gtk_widget_show (chk_finished);
 	gtk_table_attach (GTK_TABLE (table4), chk_finished, 0, 2, 6, 7,
 		(GtkAttachOptions) (GTK_FILL),
@@ -608,11 +613,13 @@ void on_icon_custom_clicked(GtkMenuItem *menuitem, gpointer user_data)
 void on_xpm_select_clicked(GtkMenuItem *menuitem, gpointer user_data)
 {
 	FileDialog dlg;
-	dlg.AddFilter(_("All supported icon formats (*.xpm,*.ico,*.png,*.jpg)"), "*.xpm|*.ico|*.png|*.jpg");
+	dlg.AddFilter(_("All supported icon formats (*.xpm,*.ico,*.png,*.jpg,*.gif)"), "*.xpm|*.ico|*.png|*.jpg|*.gif");
 	dlg.AddFilter(_("XPM icon file (*.xpm)"), "*.xpm");
 	dlg.AddFilter(_("Icon file (*.ico)"), "*.ico");
 	dlg.AddFilter(_("PNG file format (*.png)"), "*.png");
 	dlg.AddFilter(_("JPEG file format (*.jpg)"), "*.jpg");
+	dlg.AddFilter(_("GIF file format (*.gif)"), "*.gif");
+
 
 	//set initial directory from INI (store last used)
 	std::string strDefaultDir;
