@@ -71,6 +71,7 @@ void TreeView::Create()
 
 	gtk_tree_view_set_headers_visible((GtkTreeView *)treeview1, FALSE);
 	gtk_tree_view_set_enable_search((GtkTreeView *)treeview1, FALSE); 
+	g_object_set (treeview1, "level_indentation", 10, NULL);
 	gtk_widget_show (treeview1);
 
 	g_signal_connect (treeview1, "button_release_event", G_CALLBACK (treeview1_popup_menu_event_handler), NULL);
@@ -602,7 +603,30 @@ gboolean on_tree_button_release(GtkWidget *widget, GdkEventButton *event, gpoint
 		int nIdx = GetSelectedNodeIdx();
 		if(nIdx >= 0){ //execute link if exists
 			NoteNode &node = g_doc.GetNodeByIdx(nIdx);
-			ExecuteLink(node.m_objLink);
+			if(node.m_objLink.IsValid()) //execute link if exists
+				ExecuteLink(node.m_objLink);
+			else
+			{
+				//double click expands/collapses normal branch
+				//get iterator to selected node
+				GtkTreeSelection* treesel = gtk_tree_view_get_selection (GTK_TREE_VIEW(widget));
+				GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(widget));
+				GtkTreeIter iter;
+
+				if(gtk_tree_selection_get_selected(treesel, &model, &iter))
+				{
+					GtkTreePath* path1 = gtk_tree_model_get_path(model, &iter);
+					if(!gtk_tree_view_row_expanded(GTK_TREE_VIEW(widget), path1))
+					{
+						gtk_tree_view_expand_row(GTK_TREE_VIEW(widget), path1, FALSE);
+					}
+					else
+					{
+						gtk_tree_view_collapse_row(GTK_TREE_VIEW(widget), path1);
+					}
+					gtk_tree_path_free(path1);
+				}
+			}
 		}
 	}
 
@@ -616,3 +640,23 @@ gint on_popup_menu(GtkWidget *widget, gpointer data)
 	treeview_show_popup_menu();
 	return TRUE;
 }
+
+void TreeView::WrapTreeToSize(int nSize)
+{
+	GtkTreeView *treeview = (GtkTreeView *)m_pWidget;
+	GtkTreeViewColumn *column1 = gtk_tree_view_get_column(treeview, 0);
+	GList *list1 = gtk_tree_view_column_get_cell_renderers(column1);
+	GtkCellRendererText *renderer = (GtkCellRendererText *)g_list_nth_data(list1, SCREEN_IDX_TEXT);
+
+	g_object_set (G_OBJECT (renderer), 
+		"wrap-mode", PANGO_WRAP_CHAR,
+		"wrap-width", nSize, 
+		NULL);
+}
+
+void TreeView::SetTreeLines(bool bTree)
+{
+	g_object_set (G_OBJECT (m_pWidget),
+		"enable-tree-lines", bTree,
+		NULL);
+}
