@@ -23,12 +23,16 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <stdlib.h>
 
 //TOFIX remove GUI dependency through some callback?
 #include "../gui/ProgressDlg.h"
 #include "../support.h"
 
 #include <gtk/gtk.h>
+#include <glib.h>
+#include <glib/gstdio.h>
+
 int gtkMessageBox(const char *szText, int nButtons = GTK_BUTTONS_OK, int nIcon = GTK_MESSAGE_INFO); //TOFIX temp
 int cmpver(const char* szVer1, const char* szVer2);
 
@@ -166,11 +170,11 @@ int NoteDocument::Load(const char *szPath, const char *szPassword, int nFormat)
 #endif
 
 	//check if file exists
-	if(0 != access(szPath, 0))
+	if(0 != g_access(szPath, 0))
 		return DOC_LOAD_NOT_FOUND;
 
 	//test if file readable
-	if(0 != access(szPath, 04))
+	if(0 != g_access(szPath, 04))
 		return DOC_LOAD_PERMISSIONS;
 
 	//TOFIX special factory fn.
@@ -368,7 +372,7 @@ int NoteDocument::Load(const char *szPath, const char *szPassword, int nFormat)
 				(0 != strcmp(strGeneratorApp.c_str(), APP_NAME_STR) ||
 				 0 <  cmpver(strGeneratorVer.c_str(), APP_VER_STR)))
 			{
-				gtkMessageBox(_("Warning:\nThis document was created either by different application,\nor by newer version of this program.\n\nIf you edit this document, you might lose some formatting!"));
+				gtkMessageBox(_("Warning:\nThis document was created either by a different application\nNotecase and Notecase Pro are not considered the same application),\nor by a newer version of this program.\n\nIf you edit this document, you might lose some formatting!"));
 			}
 		}
 	}
@@ -403,7 +407,7 @@ int NoteDocument::Save(const char *szPath, bool bRememberPath, int nBackupFiles,
 	// - this is good to preserve file data in case Notecase crashes while saving
 
 	bool bTwoStepSave = false;
-	if(0 == access(szPath, 0))
+	if(0 == g_access(szPath, 0))
 		bTwoStepSave = true;
 
 	std::string strTargetPath(szPath);
@@ -414,11 +418,7 @@ int NoteDocument::Save(const char *szPath, bool bRememberPath, int nBackupFiles,
 	{
 		//quick FIX: delete file if it already exists
 		//TOFIX more precise fix would be to test/fix file open flags when saving
-	#ifdef _WIN32
-		::DeleteFile(szPath);
-	#else
-		remove(szPath);
-	#endif
+		g_remove(szPath);
 	}
 
 	if(FORMAT_NOTECASE_HTML == nFormat)
@@ -534,46 +534,26 @@ int NoteDocument::Save(const char *szPath, bool bRememberPath, int nBackupFiles,
 				sprintf(szPathBak, "%s.bak%d", szPath, nBakIdx);
 
 				//rename .bak file if already exists
-				#ifdef _WIN32
-					::DeleteFile(szPathBak);
-				#else
-					remove(szPathBak);
-				#endif
+				g_remove(szPathBak);
 
 				//then rename existing file as .bak (to make room for new file)
-			#ifdef _WIN32
-				bool bRes = (FALSE != ::MoveFile(szPath, szPathBak));
-			#else
-				bool bRes = (0 == rename(szPath, szPathBak));
-			#endif
+				bool bRes = (0 == g_rename(szPath, szPathBak));
 				if(!bRes)
 				{
 					//error creating backup file
 					ASSERT(FALSE);
-					#ifdef _WIN32
-						::DeleteFile(szPath);
-					#else
-						remove(szPath);
-					#endif
+					g_remove(szPath);
 				}
 			}
 			else
 			{
 				//quick FIX: delete target file if it already exists
 				//TOFIX more precise fix would be to test/fix file open flags when saving
-			#ifdef _WIN32
-				::DeleteFile(szPath);
-			#else
-				remove(szPath);
-			#endif
+				g_remove(szPath);
 			}
 
 			//move temporary file to target path
-		#ifdef _WIN32
-			bool bRes = (FALSE != ::MoveFile(strTargetPath.c_str(), szPath));
-		#else
-			bool bRes = (0 == rename(strTargetPath.c_str(), szPath));
-		#endif
+			bool bRes = (0 == g_rename(strTargetPath.c_str(), szPath));
 			if(!bRes)
 				return DOC_SAVE_ERR_OVERWRITE; // Failed to owerwrite target file
 		}
